module Equitrac
  module Utilities
    # User commands for equitrac.
    # @since 0.1.0
    module User
      # Generate the add command for a user.
      # @param user_id [String] The id of the user.
      # @param init_bal [Float] The initial balance for the account.
      # @param user_name [String] The name of the user.
      # @param min_bal [Float] The minimum balance allowed.
      # @param email [String] The e-mail of the user.
      # @param dept_name [String] The department the user is in.
      # @param primary_pin [String] The primary pin code.
      # @param secondary_pin [String] The secondary pin code.
      # @param quota [Integer] The print quota.
      # @param alternate_pin [String] The alternate pin code.
      # @param home_server [String] The home server.
      # @param locked [String] The status of the account 0 = unlocked; 1 = locked.
      # @param location [String] The user location.
      # @param additional_info [String] Any additional_info information for the account.
      # @param home_folder [String] The home folder.
      #
      # Default params are:
      #   min_bal: 1
      #   secondary_pin: ""
      #   quota: 0
      #   alternate_pin: 1
      #   home_server: ""
      #   locked: 0
      #   location: ""
      #   additional_info: 0
      #   home_folder:""
      #
      # @return [String] The equitrac command to add a user.
      #
      def add(user_id:, init_bal:, user_name:, min_bal: 0.0, email:, dept_name:, primary_pin:, secondary_pin: '""', quota: 0, alternate_pin: '""', home_server: '""', locked: 0, location: '""', additional_info: 0, home_folder: '""')
        return "add ur #{user_id} #{init_bal} \"#{user_name}\" #{min_bal} #{email} #{dept_name} #{primary_pin} #{secondary_pin} #{quota} #{alternate_pin} #{home_server} #{locked} #{location} #{additional_info} #{home_folder}"
      end

      module_function :add
    end
  end
end
